-- vim: ts=4 sw=4 ai et

if not Ammo then Ammo = {} end
Ammo.autobuy = {}

local L = Ammo.strings

local function link2name (link)
    if not link then return nil end
    local _, _, name = string.find (link, "^.*|h%[(.+)%]|h.*$")
    return name
end


-- wantedAmmo: array of ammo type names we want to purchase
function Ammo.autobuy:GetVendorIndices (wantedAmmo)
    local map = {}
    for i = 1, GetMerchantNumItems () do
        local name = GetMerchantItemInfo (i)
        for j = 1, #wantedAmmo do
            if name == wantedAmmo[j] then
                map[name] = i
            end
        end
    end
    return map
end

-- ammo_link: item link of ammo to buy
-- ammo_name: name of ammo to buy (used to confirm vendor_idx)
-- vendor_idx: the expected vendor index to purchase from
-- max_ammo_qty: the maximum number of individual (not stacks!) arrows/bullets
--     to purchase. The actual quantity bought will be <= max_ammo_qty.
function Ammo.autobuy:Restock (ammo_link, ammo_name, vendor_idx, max_ammo_qty)
    if not max_ammo_qty or max_ammo_qty <= 0 then return end

    local name, _, _, qty = GetMerchantItemInfo (vendor_idx)
    local purchased_qty = 0
    if purchased_qty + qty <= max_ammo_qty then
        -- This would be a good spot to break if we want to use a dialog first
        Ammo.addon:Print (L["Restocking "]..ammo_link.."x"..max_ammo_qty..L[" (max)"])
    end

    while purchased_qty + qty <= max_ammo_qty do
        if (name ~= ammo_name) then
            -- We should really only encounter this if we buy up all ammo
            Ammo.addon:Print (L["Restock failed - vendor out of ammo to sell?"])
            return
        end
        BuyMerchantItem (vendor_idx)
        purchased_qty = purchased_qty + qty
    end
    if purchased_qty > 0 then
        Ammo.addon:Print (L["Restocking complete. Purchased "]..ammo_link.."x"..purchased_qty)
    end
end


function Ammo.autobuy:MaybeRestock (premium_link, premium_count, lowgrade_link, lowgrade_count)
    if not Ammo.db or not Ammo.db.profile then return end
    if Ammo.db.profile.restock_premium or Ammo.db.profile.restock_lowgrade then
        local premium = link2name (premium_link)
        local lowgrade = link2name (lowgrade_link)
        -- Cache the restock count so we can override it if we're merging premium & lowgrade below
        local restock_premium_count = Ammo.db.profile.restock_premium_count
        local restock_lowgrade_count = Ammo.db.profile.restock_lowgrade_count
        -- Avoid double-purchasing if both refer to the same type.
        -- This should only happen where a type has been explicitly specified.
        -- Normally we would only get a premium type requested under these circumstances.
        local forcebuy = false
        if premium == lowgrade then
            lowgrade = nil
            lowgrade_link = nil
            if restock_lowgrade_count > restock_premium_count then
                restock_premium_count = restock_lowgrade_count
            end
            forcebuy = true
        end

        local ammos = {}
        if premium then table.insert (ammos, premium) end
        if lowgrade then table.insert (ammos, lowgrade) end

        local vendor = self:GetVendorIndices (ammos)
        if not vendor[premium] and not vendor[lowgrade] then return end -- not an ammo vendor

        if (Ammo.db.profile.restock_premium or forcebuy) and premium_link and vendor[premium] then
            local c = restock_premium_count - premium_count
            self:Restock (premium_link, premium, vendor[premium], c)
        end

        if Ammo.db.profile.restock_lowgrade and lowgrade_link and vendor[lowgrade] then
            local c = restock_lowgrade_count - lowgrade_count
            self:Restock (lowgrade_link, lowgrade, vendor[lowgrade], c)
        end
    end
end



