-- vim: ts=4 sw=4 ai et enc=utf8 fenc=utf8
if not Ammo then Ammo = {} end

local UPDATE_INTERVAL = 0.5 -- seconds
local DEFAULT_ICON = "Interface\\Icons\\INV_Misc_QuestionMark"

local ldb = LibStub:GetLibrary ("LibDataBroker-1.1")
Ammo.dataobj = ldb:NewDataObject ("Ammo-matique", { type = 'data source', text = 0, label = "Ammo:", icon = DEFAULT_ICON })

local WHITE = "|cffffffff"
local RED = "|cffff0000"

local function linkcolor (link)
    local _, _, c = string.find (link, "^(|c%x+)")
    return c
end

local function linkname (link)
    local _, _, n = string.find (link, "^|c%x+|H.+|h%[(.*)%]")
    return n
end

local ticked = 0
local ammoslot = GetInventorySlotInfo ("AmmoSlot")
local rangedslot = GetInventorySlotInfo ("RangedSlot")

local function ldb_onupdate (self, elapsed)
    ticked = ticked + elapsed
    if ticked < UPDATE_INTERVAL then return end

    ticked = 0
    local ammolink = GetInventoryItemLink ('player', ammoslot)
    if ammolink then
        local count = GetInventoryItemCount ('player', ammoslot)
        Ammo.dataobj.text = linkcolor (ammolink)..count
        Ammo.dataobj.value = count
        Ammo.dataobj.icon = GetItemIcon (ammolink)
    else
        Ammo.dataobj.text = WHITE.."0"
        Ammo.dataobj.value = 0
        Ammo.dataobj.icon = DEFAULT_ICON
    end
end

local f = CreateFrame ("Frame", "AmmoLdbFrame")
f:SetScript ('OnUpdate', ldb_onupdate)

function Ammo.dataobj:OnTooltipShow ()
    local L = Ammo.strings
    self:AddLine (WHITE..L["Available ammo"])
    self:AddLine (" ")
    local ammos = Ammo.addon:UsefulAvailableAmmo ()
    if ammos then
        for _, link in ipairs (ammos) do
            self:AddLine (linkcolor (link)..linkname(link).." x "..GetItemCount (link))
        end
    else
        if not GetInventoryItemLink ('player', rangedslot) then
            self:AddLine (RED.."<"..L["No weapon equipped"]..">")
        else
            self:AddLine (RED.."<"..L["None"]..">")
        end
    end
end

function Ammo.dataobj:OnClick (button)
    if button == "LeftButton" then
        if Ammo.addon:IsPremiumEquipped () then
            Ammo.addon:EquipLowgrade ()
        else
            Ammo.addon:EquipPremium ()
        end
    elseif button == "RightButton" then
        Ammo.addon:OpenConfigDialog ()
    end
end

